@@ -32,10 +32,6 @@
 
 /* Functions and constants in the virtual nbdkit.* module. */
 
-/* Python is broken, this MUST come first. */
-#define PY_SSIZE_T_CLEAN 1
-#include <Python.h>
-
 #include <config.h>
 
 #include <stdio.h>
@@ -165,6 +161,29 @@ parse_delay (PyObject *self, PyObject *args)
   return Py_BuildValue ("(II)", sec, nsec);
 }
 
+/* nbdkit.parse_bool */
+static PyObject *
+parse_bool (PyObject *self, PyObject *args)
+{
+  const char *str;
+  int r;
+  PyObject *ret;
+
+  if (!PyArg_ParseTuple (args, "s:parse_bool", &str))
+    return NULL;
+
+  r = nbdkit_parse_bool (str);
+  if (r == -1) {
+    PyErr_SetString (PyExc_ValueError,
+                     "Unable to parse string as boolean");
+    return NULL;
+  }
+
+  ret = r ? Py_True : Py_False;
+  Py_INCREF (ret);
+  return ret;
+}
+
 /* nbdkit.stdio_safe */
 static PyObject *
 do_stdio_safe (PyObject *self, PyObject *args)
@@ -322,6 +341,8 @@ static PyMethodDef NbdkitMethods[] = {
     "Return True if the client completed TLS authentication" },
   { "nanosleep", do_nanosleep, METH_VARARGS,
     "Sleep for seconds and nanoseconds" },
+  { "parse_bool", parse_bool, METH_VARARGS,
+    "Parse human-readable boolean strings" },
   { "parse_delay", parse_delay, METH_VARARGS,
     "Parse delay and sleep strings into (sec, nsec) pair" },
   { "parse_probability", parse_probability, METH_VARARGS,
